package com.energy.manage.common.reponse;

import java.nio.charset.Charset;

/**
 * 一些状态变量而已
 *
 * @author LIKE
 * @date 2017年1月17日 下午7:45:46
 */
public enum ConstVar {

  FAIL(-1, "失败"),
  TIMEOUT(109, "操作超时，请重新选择成绩单上传"),
  SUCCESS(200, "成功"),
  EXISTSUSER(101, "用户已存在"),
  SMSFAIL(102, "验证码错误"),
  SMSCODEFREQUENT(103, "验证码发送太频繁，请稍后重试"),
  EQUIOMENGTINUSE(118, "设备已经使用"),
  NOTNULLPARAM(105, "参数不能为空"),
  PLEASELOGIN(108, "请登录账户"),
  EXISTSUSERNOTUSE(111, "账号被停用"),
  NOTEXISTSUSER(112, "用户不存在"),
  TOKENINVALID(113, "请重新登陆用户"),

  ERRORSIGN(114, "验签失败"),
  INVALIDPARAM(115, "无效参数"),
  ISDONE(122, "测验结束，已做题"),
  SMSOVERDUE(116, "验证码已过期"),
  // 重复提交
  NOREQUEST_CODE(117, "不可重复提交"),
  ERRORPWD(-2, "密码错误"),
  ERRORVALIDATECODE(-3, "验证码错误"),
  NOTLOGIN(142, "未登录"),
  INVALIDATE_TOKEN(141, "Token失效，请重新登录"),
  PHONE_REPETITION(150, "该手机号已绑定账号请重新输入"),
  //权限资源模块响应码
  PERMISSION_ALREADY_SORT(601, "当前父id下该序号已有"),
  PERMISSION_ALREADY_ROLE(605, "当前资源已有角色关联"),
  ROLE_ALREADY_USER(606, "当前角色已有关联用户"),
  ROLE_ALREADY_PERMISSION(607, "当前角色已有关联资源"),
  ROLE_DESCRIPTION_ALREADY(620, "该角色名已有"),

  NOT_EXIST_COURSE_SERIES(10001, "系列课不存在"),
  NOT_EXIST_COURSE(10002, "课程不存在"),

  // 微信响应码
  WEIXIN_EXCEPTION_SMSOVERDUE(110020, "微信授权失败"),
  WEIXIN_EXCEPTION_CODE(110021, "微信授权code失败"),

  CONSISTENCY_NOT_PWD(110022, "两次密码输入不一致，请重新确认"),

  PUT_IN_NAME_DUBBO(210001, "名称或渠道码不能重复"),
  PUT_IN_PLAN_PROPORTION(210002, "配置权重之和应为100"),
  PUT_IN_LINK_DUBBO(210003, "落地页不能重复"),
  PUT_IN_CHILD_NUMBER(210004, "拟投放子渠道码数量需大于零"),
  PUT_IN_IMPORT(210005, "上传文件格式不正确"),
  PUT_IN_MODULE(210006, "模板表头不正确"),
  PUT_IN_DATA_DUBBO(210007, "数据重复"),
  PUT_IN_FEELING_UPDATE(210008, "上架产品不可编辑"),
  PUT_IN_FEELING_DEL(210009, "上架产品不可删除"),

  CRM_TEACHER_NAME(310001, "班主任名称重复"),
  PARAM_ID_NULL(310002, "id不能为空"),

  PERIOD_TIME_ERROR(410001, "招生时间需早于上课时间，上课时间需早于课程有效期时间，且不能重叠。"),
  PERIOD_TYPE_ERROR(410002, "直播期类型有误。"),
  PERIOD_CLASSTIME_ERROR(410003, "直播期上课时间不能重叠。"),
  PERIOD_COURCE_ERROR(410004, "直播结束回调，course_id无数据。"),
  PERIOD_UPDATE_ID(410005, "暂无数据可更改,请检查id。"),
  PERIOD_ADD_TIME(410006, "上课时间不能早于当前时间。"),
  MESSAGE_TOO_LONG(410007, "发送消息内容不能为空且需要在200字以内"),
  PERIOD_DETETE_BIND(410008, "有关联课程的营期不能删除"),
  PERIOD_DETETE_APPLY(410008, "有学员报名的营期不能删除"),

  TOOLS_PHONE(510001, "无学员信息"),
  TOOLS_PHONE_REGEXP(510002, "手机号码格式不正确"),
  TOOLS_HAS_WHITE(510003, "该用户已在白名单"),

  DATA_TRANSFER_TYPE_EMPTY(610001, "数据转换类型初始化数据不能为空"),
  DATA_TRANSFERING(610002, "系统中存在正在转换的数据，请稍后操作数据转换"),

  SAME_WIND_ENGINE_ERR_INFO(710001, "同一批次该机组存在相同分析类型的异常描述信息,不能重复添加"),

  NO_DIFINED_TYPE(810001, "非自定义评论类型,不能删除"),

  DUPLICATE_TYPE_NAME(810002, "该评论类型已存在,不能添加"),

  ANALYSISING(910001, "当前有批次正在进行分析,请稍后重试"),

  EXSIT_BATCH_NAME(1010001, "当前批次名称已存在，请重新编辑"),


  EXSIT_ON_CONFIG(1020001, "当前风场已存在启动中的自动分析配置"),

  //测评小程序
  PAPER_USER_UNBELONG_TO(3000,"哎呀，该测评已经被其他用户绑定过了，您无法进行查看~"),
  PAPER_ANSWER_SIZE_ERROR(3001,"试题未答完,请检查试题");



  /*常量~*/
  public static final String ENCODING = Charset.forName("UTF-8").name();

  public static final String ZERO = ",0";

  private ConstVar(int code, String msg) {
    this.code = code;
    this.msg = msg;
  }

  private String msg;
  private int code;

  public int getCode() {
    return code;
  }

  public void setCode(int code) {
    this.code = code;
  }

  public String getMsg() {
    return msg;
  }

  public void setMsg(String msg) {
    this.msg = msg;
  }
}

